;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xa35dc0d42ad56aa2b58d07fe49ebc165 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x5fb59f435aceed2e07e554e3b05b5284 . "./code.cg2js/cg-drag-and-drop.fasl")
(#xbc97353083a6d97995aebebf70d69bb9 . "./code.cg2js/cg-toolbar.fasl")
(#x90750056c13762b7ac6bb428e190ecd8 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x28a8e598e6a3debe7f6aca225a157c6f . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x76fc8c0feacec606756dbae1136ee8b7 . "./code.cg2js/cg-class-grid.fasl")
(#x910289036264435db45cac86536b38de . "./code.cg2js/cg-tray.fasl")
(#xd7880c8c00c8ddc03a33192255662396 . "./code.cg2js/cg-gesture-emulation.fasl")
(#xb86f9828244b40ae5daa69bd853a162c . "./code.cg2js/cg-class-support.fasl")
(#xdfc9f909a70c74c28480adbaceb76733 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xff695601610b30b6ed1a2d23532ed84c . "./code.cg2js/cg-dropping-outline.fasl")
(#x59b59afad6ca67060e0a7bedd30a3f77 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x2fdafc0daa6ecca19a279e654c0a090b . "./code.cg2js/cg-choice-list.fasl")
(#x04d5ad56535841d87b7548c28f72df23 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x7cf185a47b3942f9cfb6f46f3408f016 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x4d2f821e14016a827a772d6ad342c7c7 . "./code.cg2js/cg-timer.fasl")
(#xf31630fa40281b1db6d3602877581552 . "./code.cg2js/cg-directory-dialog.fasl")
(#x6753977df968ab48d1e0857fa79453e1 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x122663a72cea15464612c537f63c78cd . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x441df8d5fa33339d3c78d4bfb24c7874 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x0436b6e5bf0410fe2d17ad0f7f27887b . "./code.cg2js/cg-html-widget.fasl")
(#xc342772aecb3d6b9a4256c98f20cc5d7 . "./code.cg2js/cg-selected-object.fasl")
(#xa19b7bdfddb0263d74a6ba6e28fa80a5 . "./code.cg2js/cg-lamp.fasl")
(#x60a6834ac8b134f8cbfc48b25f95e480 . "./code.cg2js/cg-scroll-bar.fasl")
(#xd517f5cb002b3cb020520ce17bdd3a0a . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xc18dd795f5fa049ae30167d8caec2747 . "./code.cg2js/cg-message-dialog.fasl")
(#x31b7b269415976e033b32251340d098b . "./code.cg2js/cg-dde-utils.fasl")
(#xceb0c76cbd9b57b64c52f37a5afd507b . "./code.cg2js/cg-group-box.fasl")
(#x9d42511796df3522f02904c2aff908ca . "./code.cg2js/cg-find-string-dialog.fasl")
(#x82a857165a5a5f3db817881674dc14ff . "./code.cg2js/cg-split-bar.fasl")
(#xb2733cda9b323758cab8acb3af331314 . "./code.cg2js/cg-radio-button.fasl")
(#x0ae036e12ed6140c334cb4aad57d51eb . "./code.cg2js/cg-base.fasl")
(#x9eae6449f4561f7e4be812a37d5549a2 . "./code.cg2js/cg-paren-matching.fasl")
(#x4bb5619eac594a658455d3fc1b79079e . "./code.cg2js/cg-graphics-context.fasl")
(#x61d49841fc74eb3e5ae4127e1b73f041 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x286b98cf24041f455470519e5c032204 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xfe9b8599aacf8bac0aed8dacb9c438fd . "./code.cg2js/cg-plot-widget.fasl")
(#xbde88fae17eb53f4569e78844316bb81 . "./code.cg2js/cg-dev.fasl")
(#x2ad06d17bacc4eed9b1cb155643b7e98 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x8db0f992975b13ea5b2e0f40b9dd447f . "./code.cg2js/cg-tab-control.fasl")
(#x4996d10c8c5bcf891c0ed7bf8e88255f . "./code.cg2js/cg-fill-texture.fasl")
(#x604bdca95d752e3b5b8feaf4404d783e . "./code.cg2js/cg-menu-tooltip.fasl")
(#x98ffee122099b2f9a6dfdf2ba5a81e58 . "./code.cg2js/cg-trackbar.fasl")
(#xbafee0c7a7ada23399407e3bce37787f . "./code.cg2js/cg-nodes.fasl")
(#x95a4a3bf5af36eba872eb7803cface2f . "./code.cg2js/cg-common-control.fasl")
(#xa546001b3f1d7d4b5ce88a72af2483c9 . "./code.cg2js/cg-list-view.fasl")
(#x20f88d5e7701443034e835dc4afb1c03 . "./code.cg2js/cg-rich-edit.fasl")
(#x02a2f5a8b406a1ecd9b9115883fbad61 . "./code.cg2js/cg-project-window.fasl")
(#xf23f91f70b682a2203ac0238b1440482 . "./code.cg2js/cg-item-list.fasl")
(#xb05f23fa285b2436a04b810d0c55912d . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x9f82cf6ccc2f2ea5a854cd86e1e06998 . "./code.cg2js/cg-get-position.fasl")
(#xcf1f79414a1ac1bfd0fc80e874a9f193 . "./code.cg2js/cg-bitmap-pane.fasl")
(#x5d8298e4a86fc4b259118bcb4e3732a6 . "./code.cg2js/cg-drawable.fasl")
(#x3191ad855859aeb8ebf2083a1fc45ac7 . "./code.cg2js/cg-lettered-menu.fasl")
(#x09d2d6c4fcf26f34bb780b5eecbdd6d8 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x8249f88dd01632632d532c46dbc14506 . "./code.cg2js/cg-html-dialog.fasl")
(#xf9ad9ca91bf50a8a5d8fe6b382c0ef29 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x9c6ee437178c5d806d3f2a03ffc14d0c . "./code.cg2js/cg-utility-dialog.fasl")
(#xeae8eb9c676a62f700592929a5942df0 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xe2d108369dd5ac1924f23533b88f3acd . "./code.cg2js/cg-property.fasl")
(#xcf671467e360991fc7b06a30d0fe23fc . "./code.cg2js/cg-menu.fasl")
(#xbb595bfb04a4f6e94e1c67275c60817e . "./code.cg2js/cg-clipboard.fasl")
(#xc2c1ba978229af99283f0e02a9f3b825 . "./code.cg2js/cg-toggling-widget.fasl")
(#x13d2aabb79d1cd46a910c2c22a21ebfa . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xcf8a73445cdf8047a9cbcced3db96db2 . "./code.cg2js/cg-template-string.fasl")
(#xe955b7193201e85cc1e4bbf840582ed0 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xed0ed8eed707767dc46cf285aa25a210 . "./code.cg2js/cg-os-window.fasl")
(#x6bb4a8395ae72231a5d168fdccce7519 . "./code.cg2js/cg-grid-widget.fasl")
(#x9ca0f27ff82ab6a3931406355c4c8843 . "./code.cg2js/cg-picture-widget.fasl")
(#x7013e467aebcaa2545af52dd522d7031 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x3005be4bc0fb381fc869fb8860f81af3 . "./code.cg2js/cg-static-text.fasl")
(#x0a357e47dba5f89b93f1f0bce9e70947 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xcc0469edf91faebe3dd20917ec0e00eb . "./code.cg2js/cg-text-widget.fasl")
(#x70b8d9443a3c4432b4a022098963b9f0 . "./code.cg2js/cg-calendar.fasl")
(#x34a144a2cae5141e6244fabc854bbfe2 . "./code.cg2js/cg-check-box.fasl")
(#x7c88778329890d3af84f45a415fb0b83 . "./code.cg2js/cg-acache.fasl")
(#x5dcb23fe8a6b15696f156b8f0947c997 . "./code.cg2js/cg-wrap-string.fasl")
(#xd7bf9f84ed93bcd533d26643961740fb . "./code.cg2js/cg-bitmap-stream.fasl")
(#x8260276a5627ade963faf17490d355c8 . "./code.cg2js/cg-font-dialog.fasl")
(#xfc679abe0af6b2c19990cf3f459781ab . "./code.cg2js/cg-outline.fasl")
(#x972694e98d1426108cdeda03bde70ba5 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x53b689bb300f27e2c605069ef0ffc76d . "./code.cg2js/cg-status-bar.fasl")
(#xa1cf1c4e96b4628a72cfd032503c70c2 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x890b0438bb36b7c2696e85bd20dfd7d7 . "./code.cg2js/cg-hotspot.fasl")
(#xd45c6b579f6dff86f19b0d9badec158a . "./code.cg2js/cg-scaling-stream.fasl")
(#x4413f330075401259068b4ec1c187bcd . "./code.cg2js/cg-icon-pixmap.fasl")
(#x04159185a23713c0ef64e450e88f46fe . "./code.cg2js/cg-file-dialog.fasl")
(#xe7dc132198a8222e6548c308eaead42e . "./code.cg2js/cg-color-dialog.fasl")
(#x4bd3330987693dca10e10ca48336ab73 . "./code.cg2js/cg-get-pixmap.fasl")
(#x0b98c1a11dd2c2a8f9134ec9d23ed9d2 . "./code.cg2js/cg-object-editor.fasl")
(#x159c577c497fa96eb052b3f92feabacf . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x79af570030bf57f676067a64a2adf22d . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x4dddf764b30fd27e643fb6e06f746236 . "./code.cg2js/cg-pixmap.fasl")
(#x2f2004de2243e1dc051408d462636e37 . "./code.cg2js/cg-intersect.fasl")
(#xd18c3437b5535a9cf30bca42d766697f . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xe242dd341700a4dfe14db41e360d6233 . "./code.cg2js/cg-icon.fasl")
(#xdef90f625783f8699facdc7cd0d7e136 . "./code.cg2js/cg-yes-no-string.fasl")
(#x98db327c7394c9900899f14a89a68c79 . "./code.cg2js/cg-text-or-combo.fasl")
(#x792e6e42f1687944eec99bad42af9e15 . "./code.cg2js/cg.fasl")
(#xa086d0e5a880542d6222c4b82c846ac3 . "./code.cg2js/cg-dialog-item.fasl")
(#xf0a6e1fdeff2bd53dce47e924f1950bc . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x8d0d551c96c5c431e6abffa3658a3a72 . "./code.cg2js/cg-caret.fasl")
(#xe8865a09943b2a16ae68e835f595212e . "./code.cg2js/cg-editable-text.fasl")
(#x0baacbeb7c3ac04790d549d0a4cefb26 . "./code.cg2js/cg-choose-printer.fasl")
(#x3a91dbc28916aed905afc9deae1d5167 . "./code.cg2js/cg-yes-no-list.fasl")
(#x2cf42ffd7c5d5cb1d19f348e19114fc4 . "./code.cg2js/cg-intersect-posbox.fasl")
(#x67af66695256fcaf3a44b1e4473e56d1 . "./code.cg2js/cg-tooltip.fasl")
(#xd3147b87a3fe3f5d284e19fd636eecd1 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x63c2655ee8d4228df6cd4ff428a88b48 . "./code.cg2js/cg-combo-box.fasl")
(#xd053942ae225717e63ce2fa439bb8988 . "./code.cg2js/cg-curve.fasl")
(#x7c309536fe24f780d704c5da62657316 . "./code.cg2js/cg-web-browser.fasl")
(#x03e7945c5825d92297b9eb8dfc370485 . "./code.cg2js/cg-printing.fasl")
(#x7410b3e76f57266bd96aa855d222f10d . "./code.cg2js/cg-lisp-widget.fasl")
(#x720d1814298b21cb10caa2d5fb3efb7e . "./code.cg2js/cg-sample-file-menu.fasl")
(#x11ef2333683dbaa2bd340e51026f3460 . "./code.cg2js/cg-palette.fasl")
(#xa7559c3aec53a736ced63b0c966c30fe . "./code.cg2js/cg-os-widget.fasl")
(#x85e710f3e99fc9cc37e3492cb12a55c0 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x63fec54486e8607945593ba59c2559a6 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xf6e31899e908b6cae5c023e716b4458c . "./code.cg2js/cg-button.fasl")
(#x31b29554283361417f02aa0197f1f2fa . "./code.cg2js/cg-edit-in-place.fasl")
(#x98ab6bf98ae87162a99cce92110d7ba5 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x3a2838349150cc4f638734891d2656a1 . "./code.cg2js/cg-comtab.fasl")
(#x6edb3fb431310c697e3109011f285da7 . "./code.cg2js/cg-string-dialog.fasl")
(#x78bc8234b1ecbd6eb480455b6bf61809 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xf97a8dbb9adc59e0e4d93ffec202ed6a . "./code.cg2js/cg-up-down-control.fasl")
(#xa05f95e2455e2ff86b0defc2c120b0b5 . "./code.cg2js/cg-layout.fasl")
(#x4162cb51abe09e5f9189602473fa0a8c . "./code.cg2js/cg-chart-widget.fasl")
(#x3f9f43b8bdc9818c1d3234648df338fb . "./code.cg2js/cg-lisp-text.fasl")
(#xe7e5a6adf72ae53ef28fe1d60883673d . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x4d5ed7c40bdb5effaa9afa4b5ea08fa3 . "./code.cg2js/cg-progress-indicator.fasl")
(#xe27f37d51cc67e1add7c9bbdde2961bd . "./code.idejs/ide-inspector.fasl")
(#x53ad2ef00b05a345a2cbd56aefe1ae4e . "./code.idejs/ide-grapher.fasl")
(#xb4822c58300cae1d168cfaf512b6cadd . "./code.idejs/ide-base.fasl")
(#x1c6daaef135362aede69942fc350fc98 . "./code.idejs/ide-keyshort.fasl")
(#xb62b885ccfea989d87a2d26d259c597a . "./code.idejs/ide-dev.fasl")
(#x7f0eed80061f25303966bd2b898317fa . "./code.idejs/ide-class-browser.fasl")
(#xacedb044ef1a1286c0c96f7196a9dd62 . "./code.idejs/ide-package-list.fasl")
(#x5dcf88f3fb8f9bb543aa5fb71f570957 . "./code.idejs/ide-intro.fasl")
(#x266de63dcf86ed89d5b504be3eb3c240 . "./code.idejs/ide-class-grapher.fasl")
(#xa843cc5e814445fb66e45bb092c7194b . "./code.idejs/ide-window-list.fasl")
(#x1a41f476bb64bfb4ec583d57c6d58e58 . "./code.idejs/ide-find-definitions.fasl")
(#xbba8d62caf77d59c87854488d4548c99 . "./code.idejs/ide-trace.fasl")
(#xabcd0072dca388101ad7cb308b8be4d2 . "./code.idejs/ide-editor.fasl")
(#x926e2d4a69d029463f132fe952d0b6e0 . "./code.idejs/ide-patch-dialog.fasl")
(#x5ee6fabe43ae8ee064559a37fba5f7e1 . "./code.idejs/ide-project.fasl")
(#xf22e1c9fe8dc30ace64f76de40b0e229 . "./code.idejs/ide.fasl")
(#xdf4e68cd56acade247dd531a2176b56c . "./code.idejs/ide-apropos.fasl")
(#x38c5d26107b88fd6c1e753a084e8bfe1 . "./code.idejs/ide-acache.fasl")
(#xcce0f0b973cea19f614a51efbdbe855a . "./code.idejs/ide-clipboard.fasl")
(#x4866fcc54a14be357b982c80c0d21bec . "./code.idejs/ide-process-browser.fasl")
(#x3db099fa1cdfa374321d2276c591c123 . "./code.idejs/ide-find-in-files.fasl")
(#x18b6dc16a4499d6df486f70f87f7a80e . "./code.idejs/ide-form.fasl")
(#x4d71e565d39626da534a432cac2b32ee . "./code.idejs/ide-navigator.fasl")
(#x696b64509ebe0538a3b58ac1081d4fa0 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
